]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
Do not report a page as arch=any merely because .Dt lacks the third argument.
[mandoc.git] / mandoc.h
index 83e6d06dba3109f4251759679c65d7213dfc2e91..a4211454db4164e24851194733d1a248a27ad91c 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,4 +1,4 @@
-/*     $Id: mandoc.h,v 1.133 2014/07/04 01:50:06 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.153 2014/09/03 23:21:47 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
@@ -49,71 +49,78 @@ enum        mandocerr {
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
-       MANDOCERR_TH_MISSING, /* missing .TH macro, using "unknown 1" */
+       MANDOCERR_DT_NOTITLE, /* missing manual title, using UNTITLED: line */
+       MANDOCERR_TH_NOTITLE, /* missing manual title, using "": [macro] */
        MANDOCERR_TITLE_CASE, /* lower case character in document title */
-       MANDOCERR_MSEC_BAD, /* unknown manual section: section */
-       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch: volume */
+       MANDOCERR_MSEC_MISSING, /* missing manual section, using "": macro */
+       MANDOCERR_MSEC_BAD, /* unknown manual section: Dt ... section */
+       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch: Dt ... volume */
        MANDOCERR_DATE_MISSING, /* missing date, using today's date */
        MANDOCERR_DATE_BAD, /* cannot parse date, using it verbatim: date */
-       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order: macro */
+       MANDOCERR_OS_MISSING, /* missing Os macro, using "" */
        MANDOCERR_PROLOG_REP, /* duplicate prologue macro: macro */
-       MANDOCERR_PROLOG_BAD, /* incomplete prologue, terminated by: macro */
-       MANDOCERR_PROLOG_ONLY, /* skipping prologue macro in body: macro */
+       MANDOCERR_PROLOG_LATE, /* late prologue macro: macro */
+       MANDOCERR_DT_LATE, /* skipping late title macro: Dt args */
+       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order: macros */
 
        /* related to document structure */
-       MANDOCERR_SO, /* .so is fragile, better use ln(1): .so path */
+       MANDOCERR_SO, /* .so is fragile, better use ln(1): so path */
        MANDOCERR_DOC_EMPTY, /* no document body */
        MANDOCERR_SEC_BEFORE, /* content before first section header: macro */
-       MANDOCERR_NAMESEC_FIRST, /* first section is not "NAME": title */
+       MANDOCERR_NAMESEC_FIRST, /* first section is not NAME: Sh title */
        MANDOCERR_NAMESEC_BAD, /* bad NAME section contents: macro */
-       MANDOCERR_SEC_ORDER, /* sections out of conventional order: title */
-       MANDOCERR_SEC_REP, /* duplicate section title: title */
-       MANDOCERR_SEC_MSEC, /* unexpected section: title for ... only */
+       MANDOCERR_SEC_ORDER, /* sections out of conventional order: Sh title */
+       MANDOCERR_SEC_REP, /* duplicate section title: Sh title */
+       MANDOCERR_SEC_MSEC, /* unexpected section: Sh title for ... only */
 
        /* related to macros and nesting */
        MANDOCERR_MACRO_OBS, /* obsolete macro: macro */
        MANDOCERR_PAR_SKIP, /* skipping paragraph macro: macro ... */
        MANDOCERR_PAR_MOVE, /* moving paragraph macro out of list: macro */
        MANDOCERR_NS_SKIP, /* skipping no-space macro */
-       MANDOCERR_BLOCK_NEST, /* blocks badly nested: macro ... */
+       MANDOCERR_BLK_NEST, /* blocks badly nested: macro ... */
        MANDOCERR_BD_NEST, /* nested displays are not portable: macro ... */
        MANDOCERR_BL_MOVE, /* moving content out of list: macro */
        MANDOCERR_VT_CHILD, /* .Vt block has child macro: macro */
-       MANDOCERR_FI_SKIP, /* fill mode already enabled, skipping .fi */
-       MANDOCERR_NF_SKIP, /* fill mode already disabled, skipping .nf */
-       MANDOCERR_LINESCOPE, /* line scope broken: macro breaks macro */
+       MANDOCERR_FI_SKIP, /* fill mode already enabled, skippingfi */
+       MANDOCERR_NF_SKIP, /* fill mode already disabled, skippingnf */
+       MANDOCERR_BLK_LINE, /* line scope broken: macro breaks macro */
 
        /* related to missing arguments */
        MANDOCERR_REQ_EMPTY, /* skipping empty request: request */
        MANDOCERR_COND_EMPTY, /* conditional request controls empty scope */
        MANDOCERR_MACRO_EMPTY, /* skipping empty macro: macro */
+       MANDOCERR_ARG_EMPTY, /* empty argument, using 0n: macro arg */
        MANDOCERR_ARGCWARN, /* argument count wrong */
-       MANDOCERR_BD_NOTYPE, /* missing display type, using -ragged */
-       MANDOCERR_BL_LATETYPE, /* list type is not the first argument: arg */
-       MANDOCERR_BL_WIDTH, /* missing -width in -tag list, using 8n */
-       MANDOCERR_IT_NOHEAD, /* empty head in list item: type */
-       MANDOCERR_IT_NOBODY, /* empty list item: type */
-       MANDOCERR_FONTTYPE, /* missing font type */
+       MANDOCERR_BD_NOTYPE, /* missing display type, using -ragged: Bd */
+       MANDOCERR_BL_LATETYPE, /* list type is not the first argument: Bl arg */
+       MANDOCERR_BL_NOWIDTH, /* missing -width in -tag list, using 8n */
+       MANDOCERR_EX_NONAME, /* missing utility name, using "": Ex */
+       MANDOCERR_IT_NOHEAD, /* empty head in list item: Bl -type It */
+       MANDOCERR_IT_NOBODY, /* empty list item: Bl -type It */
+       MANDOCERR_BF_NOFONT, /* missing font type, using \fR: Bf */
+       MANDOCERR_BF_BADFONT, /* unknown font type, using \fR: Bf font */
        MANDOCERR_ARG_STD, /* missing -std argument, adding it: macro */
 
-       /* related to bad macro arguments */
-       MANDOCERR_IGNARGV, /* skipping argument */
-       MANDOCERR_ARGVREP, /* duplicate argument */
-       MANDOCERR_DISPREP, /* duplicate display type */
-       MANDOCERR_LISTREP, /* duplicate list type */
-       MANDOCERR_BADATT, /* unknown AT&T UNIX version */
-       MANDOCERR_BADBOOL, /* bad Boolean value */
-       MANDOCERR_BADFONT, /* unknown font */
-       MANDOCERR_BADSTANDARD, /* unknown standard specifier */
-       MANDOCERR_BADWIDTH, /* bad width argument */
+       /* related to bad arguments */
+       MANDOCERR_ARG_QUOTE, /* unterminated quoted argument */
+       MANDOCERR_ARG_REP, /* duplicate argument: macro arg */
+       MANDOCERR_AN_REP, /* skipping duplicate argument: An -arg */
+       MANDOCERR_BD_REP, /* skipping duplicate display type: Bd -type */
+       MANDOCERR_BL_REP, /* skipping duplicate list type: Bl -type */
+       MANDOCERR_BL_SKIPW, /* skipping -width argument: Bl -type */
+       MANDOCERR_AT_BAD, /* unknown AT&T UNIX version: At version */
+       MANDOCERR_RS_BAD, /* invalid content in Rs block: macro */
+       MANDOCERR_SM_BAD, /* invalid Boolean argument: macro arg */
+       MANDOCERR_FT_BAD, /* unknown font, skipping request: ft font */
 
        /* related to plain text */
-       MANDOCERR_NOBLANKLN, /* blank line in non-literal context */
-       MANDOCERR_BADTAB, /* tab in non-literal context */
-       MANDOCERR_EOLNSPACE, /* end of line whitespace */
-       MANDOCERR_BADCOMMENT, /* bad comment style */
-       MANDOCERR_BADESCAPE, /* bad escape sequence */
-       MANDOCERR_BADQUOTE, /* unterminated quoted string */
+       MANDOCERR_FI_BLANK, /* blank line in fill mode, using .sp */
+       MANDOCERR_FI_TAB, /* tab in filled text */
+       MANDOCERR_SPACE_EOL, /* whitespace at end of input line */
+       MANDOCERR_COMMENT_BAD, /* bad comment style */
+       MANDOCERR_ESC_BAD, /* invalid escape sequence: esc */
+       MANDOCERR_STR_UNDEF, /* undefined string, using "": name */
 
        MANDOCERR_ERROR, /* ===== start of errors ===== */
 
@@ -134,43 +141,46 @@ enum      mandocerr {
        MANDOCERR_TBLBLOCK, /* data block still open */
        MANDOCERR_TBLEXTRADAT, /* ignoring extra data cells */
 
+       /* related to document structure and macros */
        MANDOCERR_ROFFLOOP, /* input stack limit exceeded, infinite loop? */
-       MANDOCERR_BADCHAR, /* skipping bad character */
-       MANDOCERR_NAMESC, /* escaped character not allowed in a name */
-       MANDOCERR_NONAME, /* manual name not yet set */
-       MANDOCERR_NOTEXT, /* skipping text before first section header */
-       MANDOCERR_MACRO, /* skipping unknown macro */
-       MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
+       MANDOCERR_BADCHAR, /* skipping bad character: number */
+       MANDOCERR_MACRO, /* skipping unknown macro: macro */
+       MANDOCERR_IT_STRAY, /* skipping item outside list: It ... */
+       MANDOCERR_TA_STRAY, /* skipping column outside column list: Ta */
+       MANDOCERR_BLK_NOTOPEN, /* skipping end of block that is not open */
+       MANDOCERR_BLK_BROKEN, /* inserting missing end of block: macro ... */
+       MANDOCERR_BLK_NOEND, /* appending missing end of block: macro */
+
+       /* related to request and macro arguments */
+       MANDOCERR_NAMESC, /* escaped character not allowed in a name: name */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
-       MANDOCERR_RS_SKIP, /* skipping invalid content in .Rs block: macro */
-       MANDOCERR_STRAYTA, /* skipping column outside column list */
-       MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
-       MANDOCERR_SCOPEBROKEN, /* missing end of block */
-       MANDOCERR_SCOPEEXIT, /* scope open on exit */
-       MANDOCERR_UNAME, /* uname(3) system call failed */
-       MANDOCERR_NUMERIC, /* request requires a numeric argument */
-       MANDOCERR_BL_NOTYPE, /* missing list type, using -item */
-       MANDOCERR_ARGSLOST, /* line argument(s) will be lost */
+       MANDOCERR_BL_NOTYPE, /* missing list type, using -item: Bl */
+       MANDOCERR_NM_NONAME, /* missing manual name, using "": Nm */
+       MANDOCERR_OS_UNAME, /* uname(3) system call failed, using UNKNOWN */
+       MANDOCERR_ST_BAD, /* unknown standard specifier: St standard */
+       MANDOCERR_IT_NONUM, /* skipping request without numeric argument */
+       MANDOCERR_ARG_SKIP, /* skipping all arguments: macro args */
+       MANDOCERR_ARG_EXCESS, /* skipping excess arguments: macro ... args */
 
        MANDOCERR_FATAL, /* ===== start of fatal errors ===== */
 
        MANDOCERR_TOOLARGE, /* input too large */
-       MANDOCERR_NOTMANUAL, /* not a manual */
-       MANDOCERR_COLUMNS, /* column syntax is inconsistent */
-       MANDOCERR_BADDISP, /* NOT IMPLEMENTED: .Bd -file */
-       MANDOCERR_SYNTARGVCOUNT, /* argument count wrong, violates syntax */
-       MANDOCERR_SYNTCHILD, /* child violates parent syntax */
-       MANDOCERR_SYNTARGCOUNT, /* argument count wrong, violates syntax */
+       MANDOCERR_BD_FILE, /* NOT IMPLEMENTED: Bd -file */
        MANDOCERR_SO_PATH, /* NOT IMPLEMENTED: .so with absolute path or ".." */
        MANDOCERR_SO_FAIL, /* .so request failed */
-       MANDOCERR_NODOCPROLOG, /* no document prologue */
-       MANDOCERR_MEM, /* static buffer exhausted */
 
        /* ===== system errors ===== */
 
+       MANDOCERR_SYSDUP, /* cannot dup file descriptor */
+       MANDOCERR_SYSEXEC, /* cannot exec */
+       MANDOCERR_SYSEXIT, /* gunzip failed with code */
+       MANDOCERR_SYSFORK, /* cannot fork */
        MANDOCERR_SYSOPEN, /* cannot open file */
-       MANDOCERR_SYSSTAT, /* cannot stat file */
+       MANDOCERR_SYSPIPE, /* cannot open pipe */
        MANDOCERR_SYSREAD, /* cannot read file */
+       MANDOCERR_SYSSIG, /* gunzip died from signal */
+       MANDOCERR_SYSSTAT, /* cannot stat file */
+       MANDOCERR_SYSWAIT, /* wait failed */
 
        MANDOCERR_MAX
 };
@@ -416,9 +426,12 @@ int                  mchars_spec2cp(const struct mchars *,
                        const char *, size_t);
 const char      *mchars_spec2str(const struct mchars *,
                        const char *, size_t, size_t *);
-struct mparse   *mparse_alloc(int, enum mandoclevel, mandocmsg, char *);
+struct mparse   *mparse_alloc(int, enum mandoclevel, mandocmsg,
+                       const char *);
 void             mparse_free(struct mparse *);
 void             mparse_keep(struct mparse *);
+enum mandoclevel  mparse_open(struct mparse *, int *, const char *,
+                       pid_t *);
 enum mandoclevel  mparse_readfd(struct mparse *, int, const char *);
 enum mandoclevel  mparse_readmem(struct mparse *, const void *, size_t,
                        const char *);
@@ -428,6 +441,7 @@ void                  mparse_result(struct mparse *,
 const char      *mparse_getkeep(const struct mparse *);
 const char      *mparse_strerror(enum mandocerr);
 const char      *mparse_strlevel(enum mandoclevel);
+enum mandoclevel  mparse_wait(struct mparse *, pid_t);
 
 __END_DECLS